## O projektu

### Kdo za tím stojí

Slepé mapy jsou vyvíjeny na Fakultě informatiky Masarykovy univerzity, konkrétně v rámci skupiny PROSO. Mezi předchozí projekty této skupiny patří například Problem Solving Tutor.

Na vývoji Slepých map se podílí především Vít Stanislav a Jan Papoušek.

Pokud studujete na FI a máte zájem se zapojit do vývoje podobného typu systémů, případně pokud máte zájem o výzkumnou spolupráci, kontaktujte Radka Pelánka.

Náměty k rozvoji systému zasílejte na slepemapy{zavinac}googlegroups.com.

### Soukromí

Data o odpovědích jsou ukládána a jsou využívána pro výběr vhodných otázek a pro výzkumné účely. Všechna tato data jsou zpracovávána anonymně. Přihlašovací údaje (Facebook, Google) jsou použity pouze pro určení identity při opakovaných návštěvách, jinak se s nimi nepracuje.

### Zdroje

- Natural Earth Data - zdroj většiny mapových podkladů (svět, kontinenty, většina států)
- Global Administrative Areas - administrativní členění Itálie, Francie a Španělska
- OpenStreetMap Data Extracts - města České republiky a Slovenska

- Flag sprites - vlaječky států světa a USA
- Wikipedia Flags - vlaječky ostatních administrativnách celků